@@ -320,12 +320,17 @@ class AmplifyProject:
             "Effect": "Allow",
             "Resource": "*",
             "Action": [
-                "ec2:DescribeInstances",
+  "ec2:DescribeInstances",
                 "ec2:CreateNetworkInterface",
                 "ec2:AttachNetworkInterface",
-                "ec2:DescribeNetworkInterfaces",
+                "ec2:DescribeNetworkInterfaces", 
                 "ec2:DeleteNetworkInterface",
-                "cognito-idp:*",
+                "ec2:DescribeSecurityGroups",
+                "ec2:AuthorizeSecurityGroupIngress",
+                "ec2:AuthorizeSecurityGroupEgress",
+                "ec2:RevokeSecurityGroupIngress",
+                "ec2:RevokeSecurityGroupEgress",
+                "cognito-idp:*"
             ],
         }
     ],
