@@ -15,5 +15,5 @@ from velocity.db.utils import (
     safe_sort_key_none_first,
     safe_sort_key_with_default,
     group_by_fields,
-    safe_sort_grouped_rows
+    safe_sort_grouped_rows,
 )
