@@ -330,30 +330,32 @@ class Engine:
         Central method to parse driver exceptions and re-raise them as our custom exceptions.
         """
         logger = logging.getLogger(__name__)
-        
+
         # If it's already a velocity exception, just re-raise it
         if isinstance(exception, exceptions.DbException):
             raise exception
-        
+
         # Get error code and message from the SQL driver
         try:
             error_code, error_message = self.sql.get_error(exception)
         except Exception:
             error_code, error_message = None, str(exception)
-        
+
         msg = str(exception).strip().lower()
-        
+
         # Create enhanced error message with SQL query
         enhanced_message = str(exception)
         if sql:
-            enhanced_message += f"\n\nSQL Query:\n{self._format_sql_with_params(sql, parameters)}"
-        
+            enhanced_message += (
+                f"\n\nSQL Query:\n{self._format_sql_with_params(sql, parameters)}"
+            )
+
         logger.warning(
             "Database error caught. Attempting to transform: code=%s message=%s",
             error_code,
             error_message,
         )
-        
+
         # Direct error code mapping
         if error_code in self.sql.ApplicationErrorCodes:
             raise exceptions.DbApplicationError(enhanced_message) from exception
@@ -379,7 +381,7 @@ class Engine:
             raise exceptions.DbLockTimeoutError(enhanced_message) from exception
         if error_code in self.sql.RetryTransactionCodes:
             raise exceptions.DbRetryTransaction(enhanced_message) from exception
-            
+
         # Regex-based fallback patterns
         if re.search(r"key \(sys_id\)=\(\d+\) already exists.", msg, re.M):
             raise exceptions.DbDuplicateKeyError(enhanced_message) from exception
@@ -405,7 +407,7 @@ class Engine:
             raise exceptions.DbConnectionError(enhanced_message) from exception
         if "no such table:" in msg:
             raise exceptions.DbTableMissingError(enhanced_message) from exception
-        
+
         logger.error(
             "Unhandled/Unknown Error in engine.process_error",
             exc_info=True,
@@ -416,7 +418,7 @@ class Engine:
                 "sql_params": parameters,
             },
         )
-        
+
         # If we can't classify it, re-raise with enhanced message
         raise type(exception)(enhanced_message) from exception
 
@@ -426,10 +428,10 @@ class Engine:
         """
         if not sql:
             return "No SQL provided"
-            
+
         if not parameters:
             return sql
-            
+
         try:
             # Handle different parameter formats
             if isinstance(parameters, (list, tuple)):
@@ -437,45 +439,47 @@ class Engine:
                 formatted_params = []
                 for param in parameters:
                     if param is None:
-                        formatted_params.append('NULL')
+                        formatted_params.append("NULL")
                     elif isinstance(param, str):
                         # Escape single quotes and wrap in quotes
                         escaped = param.replace("'", "''")
                         formatted_params.append(f"'{escaped}'")
                     elif isinstance(param, bool):
-                        formatted_params.append('TRUE' if param else 'FALSE')
+                        formatted_params.append("TRUE" if param else "FALSE")
                     else:
                         formatted_params.append(str(param))
-                
+
                 # Replace %s placeholders with actual values
                 formatted_sql = sql
                 for param in formatted_params:
-                    formatted_sql = formatted_sql.replace('%s', param, 1)
-                    
+                    formatted_sql = formatted_sql.replace("%s", param, 1)
+
                 return formatted_sql
-                
+
             elif isinstance(parameters, dict):
                 # Handle named parameters
                 formatted_sql = sql
                 for key, value in parameters.items():
                     if value is None:
-                        replacement = 'NULL'
+                        replacement = "NULL"
                     elif isinstance(value, str):
                         escaped = value.replace("'", "''")
                         replacement = f"'{escaped}'"
                     elif isinstance(value, bool):
-                        replacement = 'TRUE' if value else 'FALSE'
+                        replacement = "TRUE" if value else "FALSE"
                     else:
                         replacement = str(value)
-                    
+
                     # Replace %(key)s or :key patterns
-                    formatted_sql = formatted_sql.replace(f'%({key})s', replacement)
-                    formatted_sql = formatted_sql.replace(f':{key}', replacement)
-                    
+                    formatted_sql = formatted_sql.replace(f"%({key})s", replacement)
+                    formatted_sql = formatted_sql.replace(f":{key}", replacement)
+
                 return formatted_sql
             else:
                 return f"{sql}\n-- Parameters: {parameters}"
-                
+
         except Exception as e:
             # If formatting fails, return original SQL with parameters shown separately
-            return f"{sql}\n-- Parameters (formatting failed): {parameters}\n-- Error: {e}"
+            return (
+                f"{sql}\n-- Parameters (formatting failed): {parameters}\n-- Error: {e}"
+            )
