@@ -7,14 +7,14 @@ class Result:
     """
     Wraps a database cursor to provide various convenience transformations
     (dict, list, tuple, etc.) and helps iterate over query results.
-    
+
     Features:
     - Pre-fetches first row for immediate boolean evaluation
     - Boolean state changes as rows are consumed: bool(result) tells you if MORE rows are available
     - Supports __bool__, is_empty(), has_results() for checking remaining results
     - Efficient iteration without unnecessary fetchall() calls
     - Caches next row to maintain accurate state without redundant database calls
-    
+
     Boolean Behavior:
     - Initially: bool(result) = True if query returned any rows
     - After each row: bool(result) = True if more rows are available to fetch
@@ -29,15 +29,15 @@ class Result:
             description = getattr(cursor, "description", []) or []
             self._headers = []
             for col in description:
-                if hasattr(col, '__getitem__'):  # Tuple-like (col[0])
+                if hasattr(col, "__getitem__"):  # Tuple-like (col[0])
                     self._headers.append(col[0].lower())
-                elif hasattr(col, 'name'):  # Object with name attribute
+                elif hasattr(col, "name"):  # Object with name attribute
                     self._headers.append(col.name.lower())
                 else:
-                    self._headers.append(f'column_{len(self._headers)}')
+                    self._headers.append(f"column_{len(self._headers)}")
         except (AttributeError, TypeError, IndexError):
             self._headers = []
-            
+
         self.__as_strings = False
         self.__enumerate = False
         self.__count = -1
@@ -49,7 +49,7 @@ class Result:
         self._cached_first_row = None
         self._first_row_fetched = False
         self._exhausted = False
-        
+
         # Pre-fetch the first row to enable immediate boolean evaluation
         self._fetch_first_row()
 
@@ -60,14 +60,16 @@ class Result:
         """
         if self._first_row_fetched or not self._cursor:
             return
-            
+
         # Don't try to fetch from INSERT/UPDATE/DELETE operations
         # These operations don't return rows, only rowcount
-        if self.__sql and self.__sql.strip().upper().startswith(('INSERT', 'UPDATE', 'DELETE', 'TRUNCATE')):
+        if self.__sql and self.__sql.strip().upper().startswith(
+            ("INSERT", "UPDATE", "DELETE", "TRUNCATE")
+        ):
             self._exhausted = True
             self._first_row_fetched = True
             return
-            
+
         try:
             raw_row = self._cursor.fetchone()
             if raw_row:
@@ -109,7 +111,9 @@ class Result:
         Return True if there are more rows available to fetch.
         This is based on whether we have a cached row or the cursor isn't exhausted.
         """
-        return self._cached_first_row is not None or (not self._exhausted and self._cursor)
+        return self._cached_first_row is not None or (
+            not self._exhausted and self._cursor
+        )
 
     def __next__(self):
         """
@@ -127,7 +131,7 @@ class Result:
                 if not row:
                     self._exhausted = True
                     raise StopIteration
-                # Try to pre-fetch the next row to update our state  
+                # Try to pre-fetch the next row to update our state
                 self._try_cache_next_row()
             except Exception as e:
                 # Handle cursor errors (e.g., closed cursor)
@@ -154,7 +158,7 @@ class Result:
         """
         if not self._cursor or self._cached_first_row is not None:
             return
-            
+
         try:
             next_row = self._cursor.fetchone()
             if next_row:
@@ -214,18 +218,22 @@ class Result:
         """
         if not self.__columns and self._cursor and hasattr(self._cursor, "description"):
             for column in self._cursor.description:
-                data = {
-                    "type_name": "unknown"  # Default value
-                }
-                
+                data = {"type_name": "unknown"}  # Default value
+
                 # Try to get type information (PostgreSQL specific)
                 try:
-                    if hasattr(column, 'type_code') and self.__tx and hasattr(self.__tx, 'pg_types'):
-                        data["type_name"] = self.__tx.pg_types.get(column.type_code, "unknown")
+                    if (
+                        hasattr(column, "type_code")
+                        and self.__tx
+                        and hasattr(self.__tx, "pg_types")
+                    ):
+                        data["type_name"] = self.__tx.pg_types.get(
+                            column.type_code, "unknown"
+                        )
                 except (AttributeError, KeyError):
                     # Keep default value
                     pass
-                
+
                 # Get all other column attributes safely
                 for key in dir(column):
                     if not key.startswith("__"):
@@ -234,8 +242,8 @@ class Result:
                         except (AttributeError, TypeError):
                             # Skip attributes that can't be accessed
                             continue
-                            
-                column_name = getattr(column, 'name', f'column_{len(self.__columns)}')
+
+                column_name = getattr(column, "name", f"column_{len(self.__columns)}")
                 self.__columns[column_name] = data
         return self.__columns
 
