@@ -3,7 +3,7 @@ import hashlib
 import sqlparse
 from psycopg2 import sql
 
-from velocity.db.core import exceptions
+from velocity.db import exceptions
 
 from .reserved import reserved_words
 from .types import TYPES
@@ -37,7 +37,7 @@ def _handle_predicate_errors(predicates, operation="WHERE"):
     """Process a list of predicates with error handling."""
     sql_parts = []
     vals = []
-    
+
     for pred, val in predicates:
         sql_parts.append(pred)
         if val is None:
@@ -46,7 +46,7 @@ def _handle_predicate_errors(predicates, operation="WHERE"):
             vals.extend(val)
         else:
             vals.append(val)
-    
+
     return sql_parts, vals
 
 
@@ -68,20 +68,31 @@ class SQL:
 
     default_schema = "public"
 
-    ApplicationErrorCodes = ["22P02", "42883"]
+    ApplicationErrorCodes = ["22P02", "42883", "42501", "42601", "25P01", "25P02"]
 
-    DatabaseMissingErrorCodes = []
+    DatabaseMissingErrorCodes = ["3D000"]
     TableMissingErrorCodes = ["42P01"]
     ColumnMissingErrorCodes = ["42703"]
     ForeignKeyMissingErrorCodes = ["42704"]
 
-    ConnectionErrorCodes = ["08001", "08S01", "57P03", "08006", "53300"]
-    DuplicateKeyErrorCodes = []  # Handled in regex check.
-    RetryTransactionCodes = []
+    ConnectionErrorCodes = [
+        "08001",
+        "08S01",
+        "57P03",
+        "08006",
+        "53300",
+        "08003",
+        "08004",
+        "08P01",
+    ]
+    DuplicateKeyErrorCodes = [
+        "23505"
+    ]  # unique_violation - no longer relying only on regex
+    RetryTransactionCodes = ["40001", "40P01", "40002"]
     TruncationErrorCodes = ["22001"]
     LockTimeoutErrorCodes = ["55P03"]
     DatabaseObjectExistsErrorCodes = ["42710", "42P07", "42P04"]
-    DataIntegrityErrorCodes = ["23503"]
+    DataIntegrityErrorCodes = ["23503", "23502", "23514", "23P01", "22003"]
 
     @classmethod
     def get_error(self, e):
@@ -111,7 +122,7 @@ class SQL:
         """
         if not table:
             raise ValueError("Table name is required.")
-            
+
         # Validate pagination parameters
         if start is not None and not isinstance(start, int):
             raise ValueError("Start (OFFSET) must be an integer.")
@@ -148,7 +159,7 @@ class SQL:
         columns = [c.strip() for c in columns if c.strip()]  # Remove empty columns
         if not columns:
             raise ValueError("No valid columns specified")
-            
+
         distinct = False
 
         # Check for DISTINCT keyword in any column
@@ -188,7 +199,7 @@ class SQL:
         new_orderby = []
         if isinstance(orderby, str):
             orderby = th.split_columns(orderby)
-            
+
         # Handle orderby references
         if isinstance(orderby, Sequence):
             for column in orderby:
@@ -200,7 +211,9 @@ class SQL:
                             # Validate direction
                             direction = direction.upper()
                             if direction not in ("ASC", "DESC"):
-                                raise ValueError(f"Invalid ORDER BY direction: {direction}")
+                                raise ValueError(
+                                    f"Invalid ORDER BY direction: {direction}"
+                                )
                             col_name = th.resolve_references(
                                 col_name.strip(), options={"alias_only": True}
                             )
@@ -213,7 +226,9 @@ class SQL:
                         )
                         new_orderby.append(resolved_col)
                 except Exception as e:
-                    raise ValueError(f"Error processing ORDER BY column '{column}': {e}")
+                    raise ValueError(
+                        f"Error processing ORDER BY column '{column}': {e}"
+                    )
 
         elif isinstance(orderby, Mapping):
             for key, val in orderby.items():
@@ -222,11 +237,13 @@ class SQL:
                     direction = str(val).upper()
                     if direction not in ("ASC", "DESC"):
                         raise ValueError(f"Invalid ORDER BY direction: {direction}")
-                    parsed_key = th.resolve_references(key, options={"alias_only": True})
+                    parsed_key = th.resolve_references(
+                        key, options={"alias_only": True}
+                    )
                     new_orderby.append(f"{parsed_key} {direction}")
                 except Exception as e:
                     raise ValueError(f"Error processing ORDER BY key '{key}': {e}")
-                    
+
         orderby = new_orderby
 
         # Handle groupby
@@ -256,7 +273,9 @@ class SQL:
 
         # FROM clause
         if th.foreign_keys:
-            sql_parts["FROM"].append(f"{TableHelper.quote(table)} AS {TableHelper.quote(alias)}")
+            sql_parts["FROM"].append(
+                f"{TableHelper.quote(table)} AS {TableHelper.quote(alias)}"
+            )
             # Handle joins
             done = []
             for key, ref_info in th.foreign_keys.items():
@@ -463,7 +482,7 @@ class SQL:
         # Create a temporary TableHelper instance for quoting
         # Note: We pass None for tx since we only need quoting functionality
         temp_helper = TableHelper(None, table)
-        
+
         keys = []
         vals_placeholders = []
         args = []
