@@ -53,7 +53,9 @@ class TestOconvFunctions(unittest.TestCase):
 
     def test_time_conv(self):
         """Tests the time_conv function with various inputs."""
-        self.assertEqual(time_conv(datetime.datetime(2023, 1, 1, 12, 30, 45)), "12:30:45")
+        self.assertEqual(
+            time_conv(datetime.datetime(2023, 1, 1, 12, 30, 45)), "12:30:45"
+        )
         self.assertEqual(time_conv(datetime.time(12, 30, 45)), "12:30:45")
         self.assertEqual(time_conv("invalid"), "invalid")
 
